pub enum CompressionMode {
Default(i32),
Dictionary(i32, Vec<u8>),
Training(usize),
}Expand description
Selects the zstd compression strategy applied to a direction of traffic.
Variants
Default(i32)
Compression mode using default zstd dictionary. 1st i32 parameter here is the compression level from -7 (fastest) to 22 (smallest).
Dictionary(i32, Vec<u8>)
Compression mode using custom dictionary.
1st i32 parameter here is the compression level from -7 (fastest) to 22
(smallest). 2nd Vec<u8> parameter here is the dictionary itself.
Training(usize)
Dictionary training mode. 1st usize parameter here describes the desired number of samples (packets) to train on. Obviously, the more samples trained on, the better theoretical compression.