EntityMessageType

Enum EntityMessageType 

pub enum EntityMessageType {
Show 15 variants Spawn, SpawnWithComponents, Despawn, InsertComponent, RemoveComponent, Publish, Unpublish, EnableDelegation, DisableDelegation, SetAuthority, Noop, RequestAuthority, ReleaseAuthority, EnableDelegationResponse, MigrateResponse,
}
Wire discriminant identifying the kind of entity/component event carried in an EntityMessage.

Variants



Spawn

Entity is to be created.



SpawnWithComponents

Entity is to be created with an initial set of components (coalesced spawn).



Despawn

Entity is to be deleted.



InsertComponent

A component is to be added to an entity.



RemoveComponent

A component is to be removed from an entity.



Publish

Entity is to be published (made visible to other users).



Unpublish

Entity publication is to be retracted.



EnableDelegation

Authority delegation is to be enabled for an entity.



DisableDelegation

Authority delegation is to be disabled for an entity.



SetAuthority

Authority status for an entity is being updated.



Noop

No-operation placeholder.



RequestAuthority

Client requests authority over an entity.



ReleaseAuthority

Client releases authority over an entity.



EnableDelegationResponse

Client acknowledges that delegation has been enabled.



MigrateResponse

Server notifies that an entity has migrated.

Implementations

Source

impl EntityMessageType

pub fn with_component_kind( &self, component_kind: &ComponentKind, ) -> EntityMessage<()>

Builds an EntityMessage<()> for component-bearing types, attaching component_kind. Panics for other variants.