pub enum LocalRequestOrResponseId {
Request(LocalRequestId),
Response(LocalResponseId),
}Expand description
Connection-local discriminated ID that identifies a packet as carrying a request or a response.
Variants
Request(LocalRequestId)
Packet carries an outgoing request with this local ID.
Response(LocalResponseId)
Packet carries a response to the request with this local ID.
Implementations
Sourceimpl LocalRequestOrResponseId
impl LocalRequestOrResponseId
Sourcepub fn is_request(&self) -> bool
pub fn is_request(&self) -> bool
Returns true if this ID represents a request.
Sourcepub fn is_response(&self) -> bool
pub fn is_response(&self) -> bool
Returns true if this ID represents a response.
Sourcepub fn to_request_id(&self) -> LocalRequestId
pub fn to_request_id(&self) -> LocalRequestId
Returns the inner LocalRequestId. Panics if this is a response.
Sourcepub fn to_response_id(&self) -> LocalResponseId
pub fn to_response_id(&self) -> LocalResponseId
Returns the inner LocalResponseId. Panics if this is a request.