pub struct BandwidthMonitor { /* private fields */ }Expand description
Rolling time-window byte counter for measuring incoming or outgoing bandwidth.
Implementations
Sourceimpl BandwidthMonitor
impl BandwidthMonitor
Sourcepub fn new(bandwidth_measure_duration: Duration) -> Self
pub fn new(bandwidth_measure_duration: Duration) -> Self
Creates a monitor with the given measurement window duration.
Sourcepub fn record_packet(&mut self, bytes: usize)
pub fn record_packet(&mut self, bytes: usize)
Records bytes bytes in the measurement window.