pub struct EntityMessageReceiver;Expand description
Stateless helper that routes incoming entity messages into per-entity ordered queues.
Implementations
Sourceimpl EntityMessageReceiver
impl EntityMessageReceiver
Sourcepub fn buffer_message<E: Copy + Hash + Eq + Debug>(
receiver: &mut ReliableReceiver<EntityMessage<E>>,
message_index: MessageIndex,
message: EntityMessage<E>,
)
pub fn buffer_message<E: Copy + Hash + Eq + Debug>( receiver: &mut ReliableReceiver<EntityMessage<E>>, message_index: MessageIndex, message: EntityMessage<E>, )
Buffer a read EntityMessage so that it can be processed later
Sourcepub fn remote_take_incoming_messages<E: Copy + Hash + Eq + Debug>(
remote_engine: &mut RemoteEngine<E>,
incoming_messages: Vec<(MessageIndex, EntityMessage<E>)>,
) -> Vec<EntityMessage<E>>
pub fn remote_take_incoming_messages<E: Copy + Hash + Eq + Debug>( remote_engine: &mut RemoteEngine<E>, incoming_messages: Vec<(MessageIndex, EntityMessage<E>)>, ) -> Vec<EntityMessage<E>>
Read all buffered EntityMessage inside the receiver and process them.
Outputs the list of EntityMessage that can be executed now, buffer the rest
into each entity’s EntityChannelReceiver
Sourcepub fn host_take_incoming_events(
host_engine: &mut HostEngine,
incoming_messages: Vec<(MessageIndex, EntityMessage<HostEntity>)>,
) -> Vec<EntityMessage<HostEntity>>
pub fn host_take_incoming_events( host_engine: &mut HostEngine, incoming_messages: Vec<(MessageIndex, EntityMessage<HostEntity>)>, ) -> Vec<EntityMessage<HostEntity>>
Feeds incoming_messages into host_engine and returns all events now ready to apply.