pub struct LocalResponseId { /* private fields */ }Expand description
Connection-scoped u8 key correlating an incoming response with the original request.
Implementations
Sourceimpl LocalResponseId
impl LocalResponseId
Sourcepub fn to_req_res_id(&self) -> LocalRequestOrResponseId
pub fn to_req_res_id(&self) -> LocalRequestOrResponseId
Wraps self as a LocalRequestOrResponseId::Response.
Sourcepub fn receive_from_remote(&self) -> LocalRequestId
pub fn receive_from_remote(&self) -> LocalRequestId
Returns the LocalRequestId that the remote assigned to the request this response answers.