pub struct PingStore { /* private fields */ }Expand description
Circular buffer that records the send time of outstanding pings indexed by PingIndex.
Implementations
Sourceimpl PingStore
impl PingStore
Sourcepub fn push_new(&mut self, now: GameInstant) -> PingIndex
pub fn push_new(&mut self, now: GameInstant) -> PingIndex
Records a new ping sent at now and returns its assigned index.
Sourcepub fn remove(&mut self, ping_index: PingIndex) -> Option<GameInstant>
pub fn remove(&mut self, ping_index: PingIndex) -> Option<GameInstant>
Removes and returns the send-time for the given ping_index, or None if not found.