pub struct SharedGlobalWorldManager;Expand description
Shared helpers for world-manager implementations that operate on the global entity registry.
Implementations
Sourcepub fn despawn_all_entities<E: Copy + Eq + Hash + Send + Sync, W: WorldMutType<E>>(
world: &mut W,
converter: &dyn EntityAndGlobalEntityConverter<E>,
global_world_manager: &dyn GlobalWorldManagerType,
entities: Vec<GlobalEntity>,
) -> Vec<EntityEvent>
pub fn despawn_all_entities<E: Copy + Eq + Hash + Send + Sync, W: WorldMutType<E>>( world: &mut W, converter: &dyn EntityAndGlobalEntityConverter<E>, global_world_manager: &dyn GlobalWorldManagerType, entities: Vec<GlobalEntity>, ) -> Vec<EntityEvent>
Removes all components from and despawns each entity in entities, returning one EntityEvent per removed component and per despawn.