InScopeEntities

Trait InScopeEntities 

pub trait InScopeEntities<E: Copy + Eq + Hash + Sync + Send> {
    // Required method
    fn has_entity(&self, entity: &E) -> bool;
}
Query interface for determining whether a given entity is currently within a receiver’s scope.

Required Methods

fn has_entity(&self, entity: &E) -> bool

Returns true if entity is currently tracked as in-scope.

Implementors