pub trait InScopeEntities<E: Copy + Eq + Hash + Sync + Send> {
// Required method
fn has_entity(&self, entity: &E) -> bool;
}Expand description
Query interface for determining whether a given entity is currently within a receiver’s scope.
Required Methods
Sourcefn has_entity(&self, entity: &E) -> bool
fn has_entity(&self, entity: &E) -> bool
Returns true if entity is currently tracked as in-scope.